@@ -2,7 +2,6 @@
 # Copyright © 2020 Max Bachmann
 # Copyright © 2011 Adam Cohen
 
-from rapidfuzz._fuzz import *
 import rapidfuzz._fuzz
 from typing import Union, Callable, Tuple
 from rapidfuzz import utils
@@ -269,7 +268,7 @@ def QRatio(s1: str, s2: str, processor: Union[bool, Callable] = True, score_cuto
     Args:
         s1 (str): first string to compare
         s2 (str): second string to compare
-		processor (Union[bool, Callable]): optional callable that reformats the strings. utils.default_process
+        processor (Union[bool, Callable]): optional callable that reformats the strings. utils.default_process
             is used by default, which lowercases the strings and trims whitespace
         score_cutoff (float): Optional argument for a score threshold as a float between 0 and 100.
             For ratio < score_cutoff 0 is returned instead. Defaults to 0.
@@ -279,4 +278,32 @@ def QRatio(s1: str, s2: str, processor: Union[bool, Callable] = True, score_cuto
 
     """
 
-    return ratio(s1, s2, processor, score_cutoff=score_cutoff)
\ No newline at end of file
+    return ratio(s1, s2, processor, score_cutoff=score_cutoff)
+
+
+def quick_lev_ratio(s1: str, s2: str, processor: Union[bool, Callable] = True, score_cutoff: float = 0) -> float:
+    """
+    Calculates a quick estimation of fuzz.ratio by counting uncommon letters between the two sentences.
+    Guaranteed to be equal or higher than fuzz.ratio and can therefore be used to filter results before using fuzz.ratio
+
+    Args:
+        s1 (str): first string to compare
+        s2 (str): first string to compare
+        processor (Union[bool, Callable]): optional callable that reformats the strings. utils.default_process
+            is used by default, which lowercases the strings and trims whitespace
+        score_cutoff (float): Optional argument for a score threshold as a float between 0 and 100.
+            For ratio < score_cutoff 0 is returned instead. Defaults to 0.
+
+    Returns:
+        float: ratio between s1 and s2 as a float between 0 and 100
+
+    """
+
+    if callable(processor):
+        s1 = processor(s1)
+        s2 = processor(s2)
+    elif processor:
+        s1 = utils.default_process(s1)
+        s2 = utils.default_process(s2)
+
+    return rapidfuzz._fuzz.quick_lev_ratio(s1, s2, score_cutoff=score_cutoff)
\ No newline at end of file
